#ifndef BOOST_SIMD_INCLUDE_CONSTANTS_ZERO_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_CONSTANTS_ZERO_HPP_INCLUDED

#include <boost/simd/constant/include/constants/zero.hpp>

#endif
